import 'reflect-metadata'
import {Service} from "typedi"
import {IPost, TPostStatus} from "../types"
import {db, pageToLimitSqlSegment} from "../includes"
import {fillIPost} from "../helpers/entity-fill"

@Service()
export class PostModel {
    async insertPost(post: IPost) {
        return db.query('insert into posts (userId,content,image,status,time) values(?,?,?,?,?)', [
            post.userId, post.content, post.image, post.status, post.time
        ])
    }

    async findPostsByStatus(status: TPostStatus, page: number) {
        let arr = await db.query('select * from posts where status=? order by time desc '
            + pageToLimitSqlSegment(page), [status])
        return arr.map((single: any) => fillIPost(single))
    }

    async findPostById(id: number) {
        let raw = await db.query('select * from posts where id=?', [id])
        if (!raw.length) {
            return null
        }
        return fillIPost(raw[0])
    }

    async setStatusByPostId(id: number, status: TPostStatus) {
        await db.query('update posts set status=? where id=?', [status, id])
    }

}
