import 'reflect-metadata'
import {Container} from "typedi"
import {PostService} from "../services/post-service"
import express from "express"
import {body, oneOf, query} from "express-validator"
import * as Validator from "validator"
import {hasValidationErrors} from "../includes"
import {JWTUserPayload} from "../types"
import expressAsyncHandler from "express-async-handler"

let postService = Container.get(PostService)

let postRouter = express.Router()
postRouter.post('/submit',
    oneOf([
        body('content').exists(),
        body('image').exists()
    ]),
    body('content').optional().notEmpty().withMessage('请输入内容')
        .escape(),
    body('image').optional().isURL({host_whitelist: [/.*\.360buyimg\.com/]}).withMessage('仅支援*.360buyimg.com下的图片'),
    expressAsyncHandler(async (req: express.Request, res: express.Response) => {
        if (hasValidationErrors(req, res)) return
        res.json(await postService.submit(req.user as JWTUserPayload, req.body.content, req.body.image))
    })
)
postRouter.get('/listPublished',
    query('page').default(1).isInt({min: 1}).withMessage('页码必须>=1'),
    expressAsyncHandler(async (req: express.Request, res: express.Response) => {
        if (hasValidationErrors(req, res)) return
        res.json(await postService.listPublished(Number(req.query.page)))
    })
)

export {postRouter}
