import 'reflect-metadata'
import {Inject, Service} from "typedi"
import {PostModel} from "../models/post-model"
import {JWTUserPayload} from "../types"
import {getTimestampInSeconds, resultJson} from "../includes"

@Service()
export class PostService {
    @Inject()
    postModel!: PostModel

    async submit(jwtUserPayload: JWTUserPayload, content: string, image: string) {
        let packet = await this.postModel.insertPost({
            userId: jwtUserPayload.id,
            content: content,
            image: image,
            status: 1,
            time: getTimestampInSeconds()
        })
        return resultJson.success(packet.insertId)
    }

    async listPublished(page: number) {
        let posts = await this.postModel.findPostsByStatus(2, page)
        return resultJson.success(posts)
    }
}
